@@ -18,14 +18,12 @@ It is used via a single directive in the .rst file
   .. support_matrix::
 
 """
-
+import configparser
 from os import path
 import re
 
 from docutils import nodes
 from docutils.parsers import rst
-import six
-from six.moves import configparser
 from sphinx.util.fileutil import copy_asset
 
 KEY_PATTERN = re.compile("[^a-zA-Z0-9_]")
@@ -222,11 +220,6 @@ class Directive(rst.Directive):
         fname = self.arguments[0]
         rel_fpath, fpath = env.relfn2path(fname)
 
-        # Handle deprecation of readfp in py3 for read_file that was not
-        # available in py2.
-        if six.PY2:
-            cfg.read_file = cfg.readfp
-
         with open(fpath) as fp:
             cfg.read_file(fp)
 
